@@ -498,57 +498,23 @@ def draggable(self, state=True, use_blit=False, update="loc"):
 _orig_matplotlib_legend_Legend.draggable = draggable
 matplotlib.axes.Axes = Axes
 
-if compare_version(matplotlib.__version__, '3.0') > 0:
-    # retain matplotlib ability to add an axes using the same arguments
-    # as a previous axes currently reuses the earlier instance.
-    from matplotlib.figure import AxesStack
-    import matplotlib.cbook as cbook
-
-    def _get(self, key):
-        """
-        Return the Axes instance that was added with *key*.
-        If it is not present, return *None*.
-        """
-        item = dict(self._elements).get(key)
-        if item is None:
-            return None
-        return item[1]
-
-    def _add(self, key, a):
-        """
-        Add Axes *a*, with key *key*, to the stack, and return the stack.
-
-        If *key* is unhashable, replace it by a unique, arbitrary object.
-
-        If *a* is already on the stack, don't add it again, but
-        return *None*.
-        """
-        # All the error checking may be unnecessary; but this method
-        # is called so seldom that the overhead is negligible.
-        if not isinstance(a, Axes):
-            raise ValueError("second argument, {!r}, is not an Axes".format(a))
-        try:
-            hash(key)
-        except TypeError:
-            key = object()
-
-        a_existing = self.get(key)
-        if a_existing is not None:
-            cbook.Stack.remove(self, (key, a_existing))
-            cbook._warn_external("key {!r} already existed; Axes is being replaced".format(key))
-            # I don't think the above should ever happen.
-
-        if a in self:
-            return None
-        self._ind += 1
-        return cbook.Stack.push(self, (key, (self._ind, a)))
-
-    AxesStack.add = _add
-    AxesStack.get = _get
 
 # ===========================
 from matplotlib import pyplot
 
+
+def use_subplot(fig, *args, **kw):
+    """
+    Same as add_subplot, but if the figure already has a subplot
+    with key (*args*, *kwargs*) then it will simply make that subplot
+    current and return it.
+    """
+    pyplot.figure(num=fig.number)
+    return pyplot.subplot(*args, **kw)
+
+
+matplotlib.figure.Figure.use_subplot = use_subplot
+
 matplotlib.style.use('classic')
 matplotlib.rcParams.update(_rc_updates)
 matplotlib.rcParams['interactive'] = True
