@@ -218,14 +218,32 @@ def time_selector(ods_tag):
         case_name = 'primary case'
     else:
         case_name = f'case {index}'
-    OMFITx.ComboBox(
+
+    def slider2combobox_sync(location):
+        update_cx_time(location)
+        time_combobox.set(eval(location))
+
+    def combobox2slider_sync(location):
+        update_cx_time(location)
+        time_slider.scale.set(eval(location))
+
+    time_slider = OMFITx.Slider(
+        "scratch['efitviewer_{}_time']".format(index),
+        [efit_times[0], efit_times[-1], 1],
+        "Time (ms)",
+        digits=0,
+        default=default_time,
+        postcommand=slider2combobox_sync,
+        refresh_every=1,
+    )
+    time_combobox = OMFITx.ComboBox(
         "scratch['efitviewer_{}_time']".format(index),
         tolist(efit_times),
-        f"Time for {case_name} ({settings['cases'][index]['device']}#{settings['cases'][index]['shot']}) (ms)",
+        "Time (ms)",
         default=default_time,
         check=is_int,
         state='normal',
-        postcommand=update_cx_time,
+        postcommand=combobox2slider_sync,
     )
     # t = settings['cases'][index].get('time', None)
     if settings['cases'][index].setdefault('time', None) is None:
