@@ -162,9 +162,9 @@ class OMFITfocusboundary(SortedDict, OMFITascii):
             else:
                 # OMFIT (or the gcf needed to check OMFIT) made a empty figure for us
                 try:
-                    ax = f.add_subplot(111, aspect='equal', projection=projection)
+                    ax = pyplot.subplot(111, aspect='equal', projection=projection)
                 except NotImplementedError:
-                    ax = f.add_subplot(111, projection=projection)
+                    ax = pyplot.subplot(111, projection=projection)
             # aesthetics
             if nd == 3:
                 ax.w_xaxis.set_pane_color((1.0, 1.0, 1.0, 0.0))
@@ -376,8 +376,8 @@ class OMFITfocusharmonics(SortedDict, OMFITascii):
                 f, axes = pyplot.subplots(3, 1, sharex=True)
             else:
                 # OMFIT (or the gcf needed to check OMFIT) made a empty figure for us
-                ax = f.add_subplot(3, 1, 1)
-                axes = np.array([ax, f.add_subplot(3, 1, 2, sharex=ax), f.add_subplot(3, 1, 3, sharex=ax)])
+                ax = pyplot.subplot(3, 1, 1)
+                axes = np.array([ax, pyplot.subplot(3, 1, 2, sharex=ax), pyplot.subplot(3, 1, 3, sharex=ax)])
         else:
             f = axes[0].get_figure()
 
