@@ -1142,7 +1142,9 @@ class OMFITtrip3Dhits(OMFITmatrix):
                     p = _print(self, 'no points with length of [{:.0f}, {:.0f}] m.'.format(*mlen), tag='e', prefix=prefix, p=p)
                 return None
         if not quiet:
-            p = _print(self, 'magnetic length in [{:.0f}, {:.0f}] m.'.format(nanmin(cc[select]), nanmax(cc[select])), prefix=prefix, p=p)
+            p = _print(
+                self, 'magnetic length in [{:.0f}, {:.0f}] m.'.format(np.nanmin(cc[select]), np.nanmax(cc[select])), prefix=prefix, p=p
+            )
 
         # limits
         pyplot.xlim(0, 360)
