@@ -1167,16 +1167,50 @@ def is_server(serverA, serverB):
 
     :return: serverB that matches serverA, otherwise False
     """
-    serverA = evalExpr(serverA)
+
+    # generate list of all possible aliases for server A
+    serverA_ = tolist(evalExpr(serverA))
+    for serverA in serverA_:
+        serverA = SERVER(serverA)
+        if serverA not in serverA_:
+            serverA_.append(serverA)
+    for serverA in serverA_:
+        try:
+            serverA = SERVER[serverA]
+        except KeyError:
+            continue
+        serverA = parse_server(serverA['server'])[2]
+        if serverA not in serverA_:
+            serverA_.append(serverA)
+
     serverB_ = tolist(evalExpr(serverB))
-    for serverB in serverB_:
-        tmp = _is_server(serverA, serverB)
-        if not tmp and serverA in OMFIT['MainSettings']['SERVER'] and serverB in OMFIT['MainSettings']['SERVER']:
-            tmp = _is_server(SERVER(serverA), SERVER(serverB))
-        if not tmp and is_localhost(serverA) and is_localhost(serverB):
-            tmp = True
-        if tmp:
-            return serverB
+
+    for serverA in serverA_:
+        for serverBname in serverB_:
+
+            # generate list of all possible aliases for server B
+            serverB__ = [serverBname]
+            for serverB in serverB__:
+                serverB = SERVER(serverB)
+                if serverB not in serverB__:
+                    serverB__.append(serverB)
+            for serverB in serverB__:
+                try:
+                    serverB = SERVER[serverB]
+                except KeyError:
+                    continue
+                serverB = parse_server(serverB['server'])[2]
+                if serverB not in serverB__:
+                    serverB__.append(serverB)
+
+            # look for match
+            for serverB in serverB__:
+                tmp = _is_server(serverA, serverB)
+                if not tmp and is_localhost(serverA) and is_localhost(serverB):
+                    tmp = True
+                if tmp:
+                    return serverBname  # return original server B name as typed by user
+
     return False
 
 
