@@ -1426,9 +1426,9 @@ class OMFITmaintree(OMFITproject):
                     del projects[item]
                     continue
                 tmp.setdefault('notes', '')
-                for k in OMFIT.prj_options_choices:
-                    if k in tmp:
-                        projects[item][k] = tmp[k]
+                for opt in OMFIT.prj_options_choices:
+                    if opt in tmp:
+                        projects[item][opt] = tmp[opt]
                         doWrite = True
 
         # if the current project has been saved put it at the top of the list
@@ -1450,11 +1450,16 @@ class OMFITmaintree(OMFITproject):
 
         # do not store console output, commands, and namespace in OMFITprojects.txt
         for item in list(projects.keys()):
-            for k in ['console', 'commands', 'namespace']:
-                if k in projects[item]:
-                    del projects[item][k]
+            for opt in ['console', 'commands', 'namespace']:
+                if opt in projects[item]:
+                    del projects[item][opt]
                     doWrite = True
 
+        # only store modules locations
+        for item in list(projects.keys()):
+            if isinstance(projects[item]['modules'], dict):
+                projects[item]['modules'] = list(projects[item]['modules'].keys())
+
         # write OMFITprojects.txt~ then move to OMFITprojects.txt if successful
         # this is to have as much of an atomic operation as possible
         if doWrite:
